<template>
    <div>
        <el-dialog :title="title" :visible="visible" :before-close="handleClose" :close-on-click-modal="false" width="50%">
            <div>
                <el-form ref="formInfo" :model="parameter" label-width="80px" :rules="rules">
                    <el-row :gutter="24">
                        <el-col :span="12">
                            <el-form-item label="名称" prop="name">
                                <el-input v-model="parameter.name" placeholder="请输入名称"></el-input>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item label="状态">
                                <el-radio-group v-model="parameter.state" style="width: 100%;">
                                    <el-radio :label="1">未认证</el-radio>
                                    <el-radio :label="2">已认证</el-radio>
                                </el-radio-group>
                            </el-form-item>
                        </el-col>
                    </el-row>
                    <el-row :gutter="24">
                        <el-col :span="12">
                            <el-form-item label="登记时间">
                                <el-date-picker v-model="parameter.time" type="date" placeholder="选择日期"
                                    style="width: 100%;">
                                </el-date-picker>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item label="行政区划">
                                <el-cascader v-model="parameter.address" :options="options" style="width: 100%;"
                                    :show-all-levels="false"></el-cascader>
                            </el-form-item>
                        </el-col>

                    </el-row>
                    <el-row :gutter="24">
                        <el-col :span="24">
                            <el-form-item label="详细地址">
                                <el-input type="textarea" :rows="2" placeholder="请输入内容" v-model="parameter.detailAddress">
                                </el-input>
                            </el-form-item>
                        </el-col>
                    </el-row>

                </el-form>
            </div>
            <span slot="footer" class="dialog-footer">
                <el-button type="primary" @click="handleSave">{{ $t('domestic.save') }}</el-button>
                <el-button @click="handleClose">{{ $t('domestic.cancel') }}</el-button>
            </span>
        </el-dialog>
    </div>
</template>

<script>
import dictUtils from '@/components/dict/DictSelectUtils.js'
export default {
    name: 'domesticDialog',
    components: {},
    data() {
        return {
            visible: false,
            title: '新增',
            rules: {
                name: [{
                    required: true,
                    message: '请输入名称',
                    trigger: 'blur'
                }],

            },
            parameter: {
                name: "",
                state: 1,
                time: "",
                address: [],
                detailAddress: ''
            },
            options: [
                {
                    value: 'chongqing',
                    label: '重庆',
                    children: [{
                        value: 'yubei',
                        label: '渝北',
                        children: [{
                            value: 'yubeijiedao',
                            label: '渝北街道'
                        }]
                    }, {
                        value: 'wanzhou',
                        label: '万州',
                        children: [{
                            value: 'wanzhoujiedao',
                            label: '万州街道'
                        }]
                    }]
                }
            ]
        }
    },
    created() {
    },
    mounted() { },
    methods: {
        //编辑
        edit(val) {
            this.title = '编辑'
            this.visible = true
        },
        //新增
        add(val) {
            this.title = '新增'
            this.visible = true
        },
        // 关闭
        handleClose() {
            this.visible = false
            this.title = ""
            this.parameter={}

        },
        // 保存
        handleSave() {
            this.$refs.formInfo.validate(valid => {
                if (valid) {
                    this.visible = false
                }
            })
        },

    }
}
</script>

<style lang="scss" scoped></style>
